@@ -10,7 +10,7 @@ use Template::Timer;
 use MRO::Compat;
 use Scalar::Util qw/blessed weaken/;
 
-our $VERSION = '0.45';
+our $VERSION = '0.46';
 $VERSION =~ tr/_//d;
 
 __PACKAGE__->mk_accessors('template');
@@ -298,7 +298,19 @@ sub template_vars {
             my $weak_ctx = $c;
             weaken $weak_ctx;
             my $sub = sub {
-                $self->$method_body($weak_ctx, @_);
+                my @args = @_;
+                my $ret;
+                eval {
+                    $ret = $self->$method_body($weak_ctx, @args);
+                };
+                if ($@) {
+                    if (blessed($@)) {
+                        die $@;
+                    } else {
+                        Catalyst::Exception->throw($@);
+                    }
+                }
+                return $ret;
             };
             $vars{$method_name} = $sub;
         }
