@@ -5,9 +5,14 @@ use warnings;
 
 use Catalyst; # qw/-Debug/;
 use Path::Class;
+use TestLogger;
+
+our $Log = TestLogger->new;
 
 our $VERSION = '0.01';
 
+__PACKAGE__->log( $Log );
+
 __PACKAGE__->config(
     name                  => 'TestApp',
     default_message       => 'hi',
@@ -21,4 +26,3 @@ __PACKAGE__->config(
 );
 
 __PACKAGE__->setup;
-
